==> safecheck-3.0.14.jar: filiale/liaoyuan/sqls/FetchUserFileByOrgChecker.sql <==
SELECT
    *
FROM
    (
        SELECT
            tp.ruhuid,
            ui.f_userinfo_id,
            ui.f_createfile_date,
            ui.f_userinfo_code,
            ua.f_street,
            ua.f_residential_area,
            ua.f_building,
            ua.f_unit,
            ua.f_floor,
            ua.f_room,
            ua.f_address,
            ui.f_user_name,
            ui.f_user_phone,
            uf.f_meter_book_num,
            ua.f_slice_area,
            uf.f_user_type,
            uf.f_meternumber,
            uf.f_meter_brand,
            tp.f_entry_status f_last_check_state,
            { f_defect_content } AS f_last_check_result,
            ui.f_comments,
            ui.version,
            ui.f_filialeid,
            tp.f_checker_name ,
            tp.f_offsite_time f_last_check_date,
			mb.f_book_slice_area
			
        FROM
            t_userinfo ui
            LEFT JOIN t_user_address ua ON ui.f_userinfo_id= ua.f_userinfo_id
            LEFT JOIN ( SELECT f_user_type,f_meter_book_num,f_userinfo_id,
            f_meternumber, f_meter_brand  FROM t_userfiles tu
            left join t_gasbrand gb on tu.f_gasbrand_id = gb.id
            WHERE f_table_state = '正常' ) uf ON ua.f_userinfo_id= uf.f_userinfo_id
			left join t_meter_book mb on mb.id=uf.f_meter_book_num
            LEFT JOIN (
                  SELECT
                  id ruhuid ,f_userinfoid,f_offsite_time,f_checker_name,f_entry_status,f_defect_content,f_state
                  FROM
                    ( SELECT *, ROW_NUMBER () over ( partition BY f_userinfoid ORDER BY f_upload_date  DESC ) AS lastcheck FROM ( SELECT * FROM t_check_paper with (nolock) WHERE { condition.condition2 } ) tp ) t
                  WHERE
                    lastcheck = 1
              ) tp ON ui.f_userinfo_id = tp.f_userinfoid

    ) a
WHERE
    { condition.condition1 }
ORDER BY
    { orderitem}

==> safecheck-3.0.72.jar: filiale/liaoyuan/sqls/FetchUserFileByOrgChecker.sql <==
SELECT
    *
FROM
    (
        SELECT
            tp.ruhuid,
            ui.f_userinfo_id,
            ui.f_createfile_date,
            ui.f_userinfo_code,
            ua.f_street,
            ua.f_residential_area,
            ua.f_building,
            ua.f_unit,
            ua.f_floor,
            ua.f_room,
            ua.f_address,
            ui.f_user_name,
            ui.f_user_phone,
            uf.f_meter_book_num,
            ua.f_slice_area,
            uf.f_user_type,
            uf.f_meternumber,
            uf.f_meter_brand,
            tp.f_entry_status f_last_check_state,
            { f_defect_content } AS f_last_check_result,
            ui.f_comments,
            ui.version,
            ui.f_filialeid,
            tp.f_checker_name ,
            tp.f_offsite_time f_last_check_date,
			mb.f_book_slice_area,
            ui.f_user_state
        FROM
            t_userinfo ui
            LEFT JOIN t_user_address ua ON ui.f_userinfo_id= ua.f_userinfo_id
            LEFT JOIN ( SELECT f_user_type,f_meter_book_num,f_userinfo_id,
            f_meternumber, f_meter_brand  FROM t_userfiles tu
            left join t_gasbrand gb on tu.f_gasbrand_id = gb.id
            WHERE f_table_state = '正常' ) uf ON ua.f_userinfo_id= uf.f_userinfo_id
			left join t_meter_book mb on mb.id=uf.f_meter_book_num
            LEFT JOIN (
                  SELECT
                  id ruhuid ,f_userinfoid,f_offsite_time,f_checker_name,f_entry_status,f_defect_content,f_state
                  FROM
                    ( SELECT *, ROW_NUMBER () over ( partition BY f_userinfoid ORDER BY f_upload_date  DESC ) AS lastcheck FROM ( SELECT * FROM t_check_paper with (nolock) WHERE { condition.condition2 } ) tp ) t
                  WHERE
                    lastcheck = 1
              ) tp ON ui.f_userinfo_id = tp.f_userinfoid

    ) a
WHERE
    { condition.condition1 }
ORDER BY
    { orderitem}
